<?php

namespace EventPortal\Http\Controllers\Admin\Delegate;

use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Table\Facades\Table;
use EventPortal\Domain\User\Models\User;
use EventPortal\Domain\Util\Breadcrumb;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Inertia\Inertia;
use Inertia\Response;

class DelegateController extends Controller
{
    public function index(): Response
    {
        $table = Table::make('delegate.index')
            ->model(new Delegate)
            ->request(request())
            ->get();

        $breadcrumbs = Breadcrumb::make()
            ->add('Delegates', route('admin.delegate.index'))
            ->get();

        return Inertia::render('Delegate/Index', [
            'data' => $table,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => 'Delegates',
        ]);
    }

    public function create(): Response
    {
        $form = Form::make('delegate.create')
            ->model(new User)
            ->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Delegates', route('admin.delegate.index'))
            ->add('Create a delegate')
            ->get();

        return Inertia::render('Delegate/Create', [
            'form' => $form,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => 'Create a delegate',
        ]);
    }

    public function store(Request $request): RedirectResponse
    {
        Form::make('delegate.create')
            ->model(new User)
            ->validate($request->all())
            ->save($request->all());

        return redirect()->route('admin.delegate.index');
    }

    public function edit(Delegate $delegate): Response
    {
        $form = Form::make('delegate.edit')->model($delegate)->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Delegates', route('admin.delegate.index'))
            ->add($delegate->name, route('admin.delegate.show', $delegate))
            ->add('Edit delegate')
            ->get();

        return Inertia::render('Delegate/Edit', [
            'form' => $form,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => $delegate->name,
        ]);
    }

    public function update(Request $request, Delegate $delegate): RedirectResponse
    {
        Form::make('delegate.edit')
            ->model($delegate)
            ->validate($request->all())
            ->save($request->all());

        return redirect()->route('admin.delegate.index');
    }

    public function show(Delegate $delegate): Response
    {
        $form = Form::make('delegate.show')->model($delegate)->render();

        $breadcrumbs = Breadcrumb::make()
            ->add('Delegates', route('admin.delegate.index'))
            ->add($delegate->name)
            ->get();

        return Inertia::render('Delegate/Show', [
            'data' => $form,
            'breadcrumbs' => $breadcrumbs,
            'pageTitle' => $delegate->name,
        ]);
    }
}
