<?php

namespace EventPortal\Http\Controllers\Admin;

use EventPortal\Domain\Permission\Models\Group;
use EventPortal\Domain\Permission\Models\Role;
use EventPortal\Domain\Permission\Resources\Group as GroupResource;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;
use Inertia\Inertia;
use Inertia\Response;

class PermissionController extends Controller
{
    public function index(): Response
    {
        $roles = Role::withoutSuperAdmin()->get();
        $columns = Arr::collapse($roles->map(static function (Role $role) {
            return [$role->name => $role->label];
        }));

        $data = Group::with('permissions')
            ->get(['id', 'name', 'label'])
            ->map(static function (Group $group) use ($roles): array {
                return (new GroupResource($group, $roles))->toArray();
            });

        return Inertia::render('Permission/Index', [
            'data' => compact('columns', 'data'),
        ]);
    }

    public function update(Request $request): RedirectResponse
    {
        $data = collect($request->all());

        $data->groupBy('roleId')->each(static function (Collection $groupedByRole, string $roleName): void {
            $role = Role::where('name', $roleName)->firstOrFail();
            $groupedByRole->groupBy('selected')
                ->each(static function (Collection $groupedBySelected, bool $selected) use ($role): void {
                    if ($selected === true) {
                        $role->givePermissionTo($groupedBySelected->pluck('permissionId')->toArray());
                        return;
                    }

                    $role->revokePermissionTo($groupedBySelected->pluck('permissionId')->toArray());
                });
        });

        return redirect()->route('admin.permission.index');
    }
}
