<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EventIndexTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function can_view_index()
    {
        factory(Event::class)->create(['name' => 'Hello World!']);
        $admin = factory(Admin::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.index',
        ]);
        $admin->givePermissionTo($permission);

        $this->assertMatchesJsonSnapshot($this->actingAs($admin->user)->get(route('admin.event.index'))->props());
    }

    /** @test **/
    public function shows_index_with_columns()
    {
        factory(Event::class)->create();
        $admin = factory(Admin::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.index',
        ]);

        $admin->givePermissionTo($permission);

        $this->actingAs($admin->user)
            ->get(route('admin.event.index') . '?cols=name')
            ->assertSessionHas('table-events-columns', [
                'name',
            ]);
    }

    /** @test **/
    public function shows_index_with_columns_session_doesnt_get_overriden_frist_time_load()
    {
        factory(Event::class)->create();
        $admin = factory(Admin::class)->create();
        $permission = factory(Permission::class)->create([
            'name' => 'event.index',
        ]);

        $admin->givePermissionTo($permission);
        $this->actingAs($admin->user);

        $this->get(route('admin.event.index') . '?cols=name')
            ->assertSessionHas('table-events-columns', [
                'name',
            ]);

        $this->get(route('admin.event.index'))
            ->assertSessionHas('table-events-columns', [
                'name',
            ]);
    }
}
